@@ -6,34 +6,35 @@
 
 #import <objectbase.h>
 #import <simtoolsgui.h>
-#import <analysis.h>
+#import <analysis.h> // EZGraph
 #import "PopSwarm.h"
 
 #import <simtoolsgui/GUISwarm.h>
 
 // Sample graphical interface swarm for models.
-@interface PopulationObserverSwarm : GUISwarm {
+@interface PopulationObserverSwarm: GUISwarm
+{
   int displayFrequency;
   
   id displayActions;
   id displaySchedule;
   
-  EZGraph * fitnessGraph;			  // graphing widget
+  id <EZGraph> fitnessGraph;			  // graphing widget
 
   // MODIFY: add display objects
   unsigned chromLen;
   float (*evalFunc) (id<Chromosome>); // Evaluation Function
-  PopulationSwarm * populationSwarm;
+  PopulationSwarm *populationSwarm;
 }
 
-+createBegin: (id) aZone;
--createEnd;
--buildObjects;
--buildActions;
--activateIn: (id) swarmContext;
++ createBegin: aZone;
+- createEnd;
+- buildObjects;
+- buildActions;
+- activateIn: swarmContext;
 
 // Other methods
--setChromLength: (unsigned) _len;
--setEvaluationFunc: (float(*)( id )) _evalFunc;
--checkToStop;
+- setChromLength: (unsigned)_len;
+- setEvaluationFunc: (float (*)(id))_evalFunc;
+- checkToStop;
 @end
