@@ -5,11 +5,12 @@
 // See file LICENSE for details and terms of copying.
 
 #import "PopObsSwarm.h"
+#import <analysis.h> // EZGraph
 
 // implementation of sample graphical interface for models.
 @implementation PopulationObserverSwarm
 
-+ createBegin: (id) aZone
++ createBegin: aZone
 {
   PopulationObserverSwarm * obj;
   id <ProbeMap> probeMap;
@@ -33,23 +34,27 @@
 }
 
 // MODIFY: possible creation finalization here
--createEnd {
+- createEnd
+{
   return [super createEnd];
 }
 
--setChromLength: (unsigned) _len {
+- setChromLength: (unsigned)_len
+{
   chromLen = _len;
   return self;
 }
 
--setEvaluationFunc: (float(*)( id )) _evalFunc {
-    evalFunc = _evalFunc;
-    return self;
+- setEvaluationFunc: (float(*)(id))_evalFunc
+{
+  evalFunc = _evalFunc;
+  return self;
 }
 
--buildObjects {
+- buildObjects
+{
   id modelZone;
-
+  
   [super buildObjects];
   
   modelZone = [Zone create: [self getZone]];
@@ -116,21 +121,23 @@
   return self;
 }  
 
--activateIn: (id) swarmContext {
+- activateIn: swarmContext
+{
   [super activateIn: swarmContext];
-
+  
   [populationSwarm activateIn: self];
   [displaySchedule activateIn: self];
   
   return [self getSwarmActivity];
 }
 
--checkToStop {
+- checkToStop
+{
   if ( [populationSwarm getGenerations] 
-       <= [populationSwarm getGenerationCount]) {
+       <= [populationSwarm getGenerationCount])
     [controlPanel setStateStopped];
-  }
   return self;
 }
+
 @end
 
