@@ -6,13 +6,16 @@
 float evalFunc( id<Chromosome> a );
 
 int
-main(int argc, char ** argv) {
+main (int argc, const char **argv)
+{
   id topLevelSwarm;
 
   initSwarm(argc, argv);
 
   if ( swarmGUIMode == 1 ) {
-    topLevelSwarm = [PopulationObserverSwarm create: globalZone];
+    topLevelSwarm = [PopulationObserverSwarm createBegin: globalZone];
+    SET_WINDOW_GEOMETRY_RECORD_NAME (topLevelSwarm);
+    topLevelSwarm = [topLevelSwarm createEnd];
   } else {
     topLevelSwarm = [PopulationBatchSwarm create: globalZone];
   }
